@@ -2,10 +2,11 @@
 
 lfSolver<-function(z, a, extra) {
     x <- z
+    if ((is.null(extra$weights)) || (is.null(extra$y))) stop("lfSolver needs the additional arguments y and weights!")
     w <- extra$weights
     z <- extra$y
     n <- length(z)
-    if (length(a)==0) return(list(x=z,lbd=0,f=0))
+    if (length(a)==0) return(list(x=z,lbd=NULL,f=0,gx=rep(0,n))) 
     if (is.vector(a)) a<-matrix(a,1,length(a))
     indi<-mkIndi(a,n)
     h<-crossprod(indi,w%*%indi); r<-drop(crossprod(indi,w%*%z))
